package Acme::CPAN::Testers::PreReqNotIndexed;
BEGIN {
  $Acme::CPAN::Testers::PreReqNotIndexed::VERSION = '0.02';
}

#ABSTRACT: see what gets generated when a prereq isn't indexed

use strict;
use warnings;
use BINGOS::BadModule;

q[Integer semper];


__END__
=pod

=head1 NAME

Acme::CPAN::Testers::PreReqNotIndexed - see what gets generated when a prereq isn't indexed

=head1 VERSION

version 0.02

=head1 DESCRIPTION

Acme::CPAN::Testers::PreReqNotIndexed defines a prerequisite module that isn't in
the CPAN indexes to see what report gets generated by CPAN Testers

That's pretty much it, really.

=head1 AUTHOR

Chris Williams <chris@bingosnet.co.uk>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Chris Williams.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

